arclib
======

arclib aims at providing a unified API for accessing Python's archive formats. In
particular, it provides the following APIs:

- Basic, one-shot: For gzip, bzip2, and LZMA. Supports one-shot compression and
  decompression.
- Basic, incremental: For bzip2 and LZMA. Supports incremental compression and
  decompression.
- Complex: For zip and tar. Supports accessing the various members and their
  respective information.

Links
*****

- `PyPI <https://pypi.python.org/pypi/arclib>`_
- `Docs <http://arclib.readthedocs.org/en/latest/>`_
